import { Ast, CompileOptions, Warning, Var, CssResult } from '../interfaces.js';
import Stats from '../Stats.js';
import { Identifier, Node, ImportDeclaration, ExportNamedDeclaration, Declaration, ExportDefaultDeclaration, ExportAllDeclaration } from 'estree';
import Fragment from './nodes/Fragment.js';
import { Scope } from './utils/scope.js';
import Element from './nodes/Element.js';
import Stylesheet from './css/Stylesheet.js';
import Slot from './nodes/Slot.js';
import Tag from './nodes/shared/Tag.js';
import TemplateScope from './nodes/shared/TemplateScope.js';
import Node1 from './nodes/shared/Node.js';
import { INode } from './nodes/interfaces.js';
export default class Component {
    /**
     * @param  ast
     * @param  source
     * @param  name
     * @param  compile_options
     * @param  stats
     * @param  warnings
     */
    constructor(ast: Ast, source: string, name: string, compile_options: CompileOptions, stats: Stats, warnings: Warning[]);
    /** @type {Stats} */
    stats: Stats;
    /** @type {Warning[]} */
    warnings: Warning[];
    /** @type {Set<string>} */
    ignores: Set<string>;
    /** @type {Array<Set<string>>} */
    ignore_stack: Array<Set<string>>;
    /** @type {Ast} */
    ast: Ast;
    /** @type {Ast} */
    original_ast: Ast;
    /** @type {string} */
    source: string;
    /** @type {Identifier} */
    name: Identifier;
    /** @type {CompileOptions} */
    compile_options: CompileOptions;
    /** @type {Fragment} */
    fragment: Fragment;
    /** @type {Scope} */
    module_scope: Scope;
    /** @type {Scope} */
    instance_scope: Scope;
    /** @type {WeakMap<Node, Scope>} */
    instance_scope_map: WeakMap<Node, Scope>;
    /** @type {ComponentOptions} */
    component_options: ComponentOptions;
    /** @type {string} */
    namespace: string;
    /** @type {string} */
    tag: string;
    /** @type {boolean} */
    accessors: boolean;
    /** @type {Var[]} */
    vars: Var[];
    /** @type {Map<string, Var>} */
    var_lookup: Map<string, Var>;
    /** @type {ImportDeclaration[]} */
    imports: ImportDeclaration[];
    /** @type {ExportNamedDeclaration[]} */
    exports_from: ExportNamedDeclaration[];
    /** @type {ExportNamedDeclaration[]} */
    instance_exports_from: ExportNamedDeclaration[];
    /** @type {Set<Node>} */
    hoistable_nodes: Set<Node>;
    /** @type {Map<string, Node>} */
    node_for_declaration: Map<string, Node>;
    /** @type {Array<Node | Node[]>} */
    partly_hoisted: Array<Node | Node[]>;
    /** @type {Array<Node | Node[]>} */
    fully_hoisted: Array<Node | Node[]>;
    /**
     * @type {Array<{
     * 		assignees: Set<string>;
     * 		dependencies: Set<string>;
     * 		node: Node;
     * 		declaration: Node;
     * 	}>}
     */
    reactive_declarations: Array<{
        assignees: Set<string>;
        dependencies: Set<string>;
        node: Node;
        declaration: Node;
    }>;
    /** @type {Set<Node>} */
    reactive_declaration_nodes: Set<Node>;
    /** */
    has_reactive_assignments: boolean;
    /** @type {Set<string>} */
    injected_reactive_declaration_vars: Set<string>;
    /** @type {Map<string, Identifier>} */
    helpers: Map<string, Identifier>;
    /** @type {Map<string, Identifier>} */
    globals: Map<string, Identifier>;
    /** @type {Map<string, Set<string>>} */
    indirect_dependencies: Map<string, Set<string>>;
    /** @type {string} */
    file: string;
    /** @type {(c: number) => { line: number; column: number }} */
    locate: (c: number) => {
        line: number;
        column: number;
    };
    /** @type {Element[]} */
    elements: Element[];
    /** @type {Stylesheet} */
    stylesheet: Stylesheet;
    /** @type {Map<string, Identifier>} */
    aliases: Map<string, Identifier>;
    /** @type {Set<string>} */
    used_names: Set<string>;
    /** @type {Set<string>} */
    globally_used_names: Set<string>;
    /** @type {Map<string, Slot>} */
    slots: Map<string, Slot>;
    /** @type {Set<string>} */
    slot_outlets: Set<string>;
    /** @type {Tag[]} */
    tags: Tag[];
    /**
     * @param  node
     * @param  variable
     * @param  add_to_lookup
     */
    add_var(node: Node, variable: Var, add_to_lookup?: any): void;
    /**
     * @param  node
     * @param  name
     */
    add_reference(node: Node, name: string): void;
    /** @param {string} name */
    alias(name: string): Identifier;
    /** @param {Element} element */
    apply_stylesheet(element: Element): void;
    /** @param {string} name */
    global(name: string): Identifier;
    /** @param {{ js: Node[]; css: CssResult }} [result] */
    generate(result?: {
        js: Node[];
        css: CssResult;
    }): {
        js: {
            code: string;
            map: any;
        };
        css: CssResult;
        ast: Ast;
        warnings: Warning[];
        vars: Var[];
        stats: {
            timings: {
                total: number;
            };
        };
    };
    /**
     * @param  name
     * @param  [scope]
     * @returns 
     */
    get_unique_name(name: string, scope?: Scope): Identifier;
    get_unique_name_maker(): (name: string) => Identifier;
    /** @returns {Var[]} */
    get_vars_report(): Var[];
    /**
 * @param  pos
 * @param  e
     */
    error(pos: {
        start: number;
        end: number;
    }, e: {
        code: string;
        message: string;
    }): void;
    /**
 * @param  pos
 * @param  warning
     */
    warn(pos: {
        start: number;
        end: number;
    }, warning: {
        code: string;
        message: string;
    }): void;
    /** @param {any} node */
    extract_imports(node: any): void;
    /**
     * @param  node
     * @param  module_script
     */
    extract_exports(node: any, module_script?: any): void | Declaration;
    /**
     * @private
     * @param  node
     * @param  module_script
     */
    private _extract_exports;
    /** @param {any} script */
    extract_javascript(script: any): any;
    walk_module_js(): void;
    walk_instance_js_pre_template(): void;
    walk_instance_js_post_template(): void;
    post_template_walk(): void;
    track_references_and_mutations(): void;
    /**
     * @param  node
     * @param  parent
     * @param  prop
     * @param  scope
     */
    warn_on_undefined_store_value_references(node: Node, parent: Node, prop: string | number | symbol, scope: Scope): void;
    /**
     * @param  node
     * @param  scope
     * @param  timeout
     * @returns 
     */
    loop_protect(node: any, scope: Scope, timeout: number): Node;
    /** @param {(variable: Var) => Node[]} get_insert */
    rewrite_props(get_insert: (variable: Var) => Node[]): void;
    hoist_instance_declarations(): void;
    extract_reactive_declarations(): void;
    check_if_tags_content_dynamic(): void;
    /**
     * @param  name
     * @param  node
     * @param  template_scope
     * @param  [owner]
     */
    warn_if_undefined(name: string, node: any, template_scope: TemplateScope, owner?: Node1<any, INode>): void;
    /** @param {any} ignores */
    push_ignores(ignores: any): void;
    pop_ignores(): void;
}
export type ComponentOptions = {
    namespace?: string;
    immutable?: boolean;
    accessors?: boolean;
    preserveWhitespace?: boolean;
    customElement?: {
        tag: string | null;
        shadow?: 'open' | 'none';
        props?: Record<string, {
            attribute?: string;
            reflect?: boolean;
            type?: 'String' | 'Boolean' | 'Number' | 'Array' | 'Object';
        }>;
    };
};
